@@ -127,9 +127,9 @@ void ObexFtpDaemon::offlineMode()
     QHash<QString, ObexSession*>::const_iterator i = d->m_sessionMap.constBegin();
     while (i != d->m_sessionMap.constEnd()) {
         if (d->m_sessionMap[i.key()]) {
-            d->m_sessionMap[i.key()]->Disconnect().waitForFinished();
-            d->m_sessionMap[i.key()]->Close().waitForFinished();
-            delete d->m_sessionMap[i.key()];
+            d->m_sessionMap[i.key()]->Disconnect();
+            d->m_sessionMap[i.key()]->Close();
+            d->m_sessionMap[i.key()]->deleteLater();
         }
         d->m_sessionMap.remove(i.key());
         ++i;
@@ -313,6 +313,11 @@ void ObexFtpDaemon::SessionConnected(QDBusObjectPath path)
 
     QString address = getAddressFromSession(path.path());
 
+    if (address.isEmpty() || !d->m_sessionMap.contains(address)) {
+        kDebug() << "This seasson is from another process";
+        return;
+    }
+
     d->m_sessionMap[address]->setStatus(ObexSession::Connected);
 
     connect(d->m_sessionMap[address], SIGNAL(sessionTimeout()), this, SLOT(sessionDisconnected()));
